#ifndef Application_h
#define Application_h

// $Id: Application.h,v 1.13 2013/10/25 09:37:15 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "Config.h"
#include "Counter.h"

#include <QBasicTimer>

class SystemTrayIcon;
class StateFrame;
class LogDialog;
class MessageQueue;

//! Main Window singleton object
class Application: public BaseApplication, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! usage
    static void usage( void );

    //! constructor
    Application( CommandLineArguments );

    //! destructor
    ~Application( void );

    //! create all widgets
    bool realizeWidget( void );

    //! cvs log frame
    SystemTrayIcon& systemTrayIcon( void ) const
    { return *systemTrayIcon_; }

    //! message queue
    MessageQueue& messageQueue( void ) const
    { return *messageQueue_; }

    //! message queue
    LogDialog& logDialog( void ) const
    { return *logDialog_; }

    //! toggle log action
    QAction& toggleLogAction( void ) const
    { return *toggleLogAction_; }

    protected:

    //! timer event
    virtual void timerEvent( QTimerEvent* );

    protected Q_SLOTS:

    //! opens MessageBox about Qt version
    void _about( void )
    { BaseApplication::_about( "Qssh", VERSION, BUILD_TIMESTAMP ); }

    //! configuration
    void _configuration( void );

    //! update message queue geometry
    void _updateMessageQueue( void );

    //! run keychain
    void _runKeychain( void );

    private:

    //! cvs log display frame
    SystemTrayIcon *systemTrayIcon_;

    //! message queue
    MessageQueue* messageQueue_;

    //! log dialog
    LogDialog* logDialog_;

    //! toggle log dialog action
    QAction* toggleLogAction_;

    //! connection timer
    QBasicTimer timer_;

};

#endif
