// $Id: ConnectionAttributesModel.cpp,v 1.7 2013/04/29 18:27:14 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConnectionAttributesModel.h"
#include "Debug.h"
#include "IconEngine.h"
#include "Icons.h"

//_______________________________________________
const QString ConnectionAttributesModel::columnTitles_[ ConnectionAttributesModel::nColumns ] =
{
    tr( "Name" ),
    tr( "Host" ),
    tr( "User" ),
    tr( "Options" )
};

//______________________________________________________________________
ConnectionAttributesModel::ConnectionAttributesModel( QObject* parent ):
    ListModel<ConnectionAttributes>( parent ),
    Counter( "ConnectionDialog::ConnectionAttributesModel" ),
    icon_( IconEngine::get( ICONS::CONNECTION ) )
{}

//______________________________________________________________________
QVariant ConnectionAttributesModel::data( const QModelIndex& index, int role ) const
{
    Debug::Throw( "ConnectionAttributesModel::data.\n" );

    // check index, role and column
    if( !index.isValid() ) return QVariant();

    // retrieve associated file info
    const ConnectionAttributes& attributes( get()[index.row()] );

    // return text associated to file and column
    if( role == Qt::DisplayRole ) {

        switch( index.column() )
        {
            case ConnectionAttributesModel::NAME: return attributes.name();
            case ConnectionAttributesModel::HOST: return attributes.host();
            case ConnectionAttributesModel::USER: return attributes.user();
            case ConnectionAttributesModel::OPTIONS: return attributes.options();
            default: return QVariant();
        }

    } else if( role == Qt::DecorationRole && index.column() == NAME ) {

        return icon_;

    }

    return QVariant();

}

//______________________________________________________________________
QVariant ConnectionAttributesModel::headerData(int section, Qt::Orientation orientation, int role ) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}
