// $Id: Menu.cpp,v 1.15 2013/10/25 09:37:16 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Application.h"
#include "Debug.h"
#include "DebugMenu.h"
#include "IconEngine.h"
#include "Menu.h"
#include "Singleton.h"
#include "Util.h"
#include "XmlOptions.h"

//__________________________________________________
Menu::Menu( QWidget* parent ):
    QMenu( parent ),
    Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu" );

    setSeparatorsCollapsible( false );
    QAction* separator = addSeparator();
    separator->setText( "Qssh" );
    separator->setIcon( IconEngine::get( XmlOptions::get().raw("ICON_PIXMAP" ) ) );

    Application& application( *Singleton::get().application<Application>() );

    addAction( &application.aboutAction() );
    addAction( &application.aboutQtAction() );
    DebugMenu *debugMenu( new DebugMenu( this ) );
    addAction( debugMenu->menuAction() );
    debugMenu->menuAction()->setVisible( false );

    addSeparator();
    addAction( &application.configurationAction() );

    separator_ = addSeparator();
    addAction( &application.closeAction() );

}

//____________________________________________________________
Menu::~Menu( void )
{ Debug::Throw( "Menu::~Menu.\n" ); }
