#ifndef TunnelAttributes_h
#define TunnelAttributes_h

// $Id: TunnelAttributes.h,v 1.7 2013/04/29 18:27:14 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QDomDocument>
#include <QDomElement>
#include <QStringList>
#include <QList>

//! tunnel attributes
class TunnelAttributes: public Counter
{

    public:

    typedef QList<TunnelAttributes> List;

    //! constructor
    TunnelAttributes( void );

    //! constructor
    TunnelAttributes( const QDomElement& );

    //! dom element
    QDomElement domElement( QDomDocument& ) const;

    //! equal to operator
    bool operator == (const TunnelAttributes& attributes) const
    {
        return
            host_ == attributes.host_ &&
            localPort_ == attributes.localPort_ &&
            remotePort_ == attributes.remotePort_;
    }

    //! less than operator
    bool operator < ( const TunnelAttributes& attributes ) const
    { return localPort_ < attributes.localPort_; }

    //! get settings error
    QStringList errors( void ) const;

    //! true if valid
    bool isValid( void ) const;

    //! host
    QString host( void ) const
    { return host_; }

    //! host
    TunnelAttributes& setHost( const QString& host )
    {
        host_ = host;
        return *this;
    }

    //! port
    unsigned int localPort( void ) const
    { return localPort_; }

    //! port
    TunnelAttributes& setLocalPort( const unsigned int& port )
    {
        localPort_ = port;
        return *this;
    }

    //! port
    unsigned int remotePort( void ) const
    { return remotePort_; }

    //! port
    TunnelAttributes& setRemotePort( const unsigned int& port )
    {
        remotePort_ = port;
        return *this;
    }

    //! validity
    class ValidFTor
    {

        public:

        //! predicate
        bool operator() (const TunnelAttributes& attributes )
        { return attributes.isValid(); }

    };

    //! validity
    class InvalidFTor
    {

        public:

        //! predicate
        bool operator() (const TunnelAttributes& attributes )
        { return !attributes.isValid(); }

    };

    private:

    //! host
    QString host_;

    //! port
    unsigned int localPort_;

    //! port
    unsigned int remotePort_;

};

#endif
